@@ -3,11 +3,11 @@ Doctests for FormConvert
 """
 import doctest
 import logging
-logging.basicConfig(level=logging.DEBUG)
+logging.basicConfig(level=logging.ERROR)
 
 import sys; sys.path.append('../')
 import formbuild
 
-doctest.testfile('../doc/source/manual.rst', optionflags=doctest.ELLIPSIS)
 doctest.testmod(formbuild)
+doctest.testfile('../doc/source/manual.rst', optionflags=doctest.ELLIPSIS)
 
